strip_and_patch

Function strip_and_patch 

fn strip_and_patch(root: &Path, dist_dir: &Path) -> Result<()>
Strips debug symbols and removes RPATH from the binary and all libraries.

RPATH is removed so the libraries resolve against the device’s default linker search paths rather than the build host’s paths.