pub fn run(args: RunEmulatorArgs) -> Result<()>Expand description
Ensures prerequisites are built then launches the emulator.
Errors
Returns an error if the native setup, documentation build, or emulator launch fails.
pub fn run(args: RunEmulatorArgs) -> Result<()>Ensures prerequisites are built then launches the emulator.
Returns an error if the native setup, documentation build, or emulator launch fails.