pub fn library_source(name: &str) -> Result<LibrarySource>Expand description
Returns the source descriptor for a named library.
Errors
Returns an error if name is not a known library.
pub fn library_source(name: &str) -> Result<LibrarySource>Returns the source descriptor for a named library.
Returns an error if name is not a known library.