current_version

Function current_version 

pub fn current_version() -> Result<String>
Returns the version of the cadmus binary crate from its Cargo.toml.

Errors

Returns an error if the workspace root cannot be found, the Cargo.toml cannot be read, or the version field is missing.