pub(crate) fn save_json(
root: &Path,
cargo_args: &[&str],
dest: &Path,
) -> Result<()>Expand description
Runs cargo clippy --message-format=json and writes every output line to
dest, creating or truncating the file.
Does not apply -D warnings — the exit status of clippy is ignored so
that artifact collection always succeeds even when warnings are present.
Errors
Returns an error if the process cannot be spawned or the file cannot be written.